searchData={"content_type":"text/markdown","items":[{"doc":"","ref":"Bio.Restriction.Enzyme.Core.html","title":"Bio.Restriction.Enzyme.Core","type":"module"},{"doc":"Module for building out the actual data structure that will be generated in\ncode.\n\nEach enzyme will be defined as a struct under the `Bio.Restriction.Enzyme`\nnamespace. This struct will be populated with the minimal data needed for the\nuse in digestion and sequence validations.\n\nFurther additions to the data can be requested by opening an issue.\n\nThe current data preserved are:\n\nblunt?: boolean\ncut_1: number\ncut_2: number\ncut_3: number\ncut_4: number\nname: string\npattern: string\nsuppliers: [string...]\n\n\nThe value of `suppliers` is a string list of the Supplier Codes. These are\nrelated to company names using the emboss_s file, and can be related with the\n`Bio.Restriction.Suppliers` module.","ref":"Mix.Tasks.Bio.Restriction.Build.html","title":"mix bio.restriction.build","type":"task"},{"doc":"","ref":"Mix.Tasks.Bio.Restriction.Build.html#run/1","title":"Mix.Tasks.Bio.Restriction.Build.run/1","type":"function"},{"doc":"","ref":"Mix.Tasks.Bio.Restriction.Build.html#sourcify/1","title":"Mix.Tasks.Bio.Restriction.Build.sourcify/1","type":"function"},{"doc":"","ref":"Mix.Tasks.Bio.Restriction.Build.html#stringify/1","title":"Mix.Tasks.Bio.Restriction.Build.stringify/1","type":"function"},{"doc":"","ref":"Mix.Tasks.Bio.Restriction.Build.html#to_source/1","title":"Mix.Tasks.Bio.Restriction.Build.to_source/1","type":"function"},{"doc":"This runs a series of downloads to get the relevant files from REBASE\n\nThese are used to generate the restriction enzyme data.\nRequires your email and a directory as the only arguments. The email is used\nfor the download of the data through FTP from REBASE. The directory is where\nthe files should be downloaded to.","ref":"Mix.Tasks.Bio.Restriction.Download.html","title":"mix bio.restriction.download","type":"task"},{"doc":"","ref":"Mix.Tasks.Bio.Restriction.Download.html#run/1","title":"Mix.Tasks.Bio.Restriction.Download.run/1","type":"function"},{"doc":"Update the library of restriction enzymes according to REBASE data.","ref":"Mix.Tasks.Bio.Restriction.Update.html","title":"mix bio.restriction.update","type":"task"},{"doc":"","ref":"Mix.Tasks.Bio.Restriction.Update.html#run/1","title":"Mix.Tasks.Bio.Restriction.Update.run/1","type":"function"},{"doc":"","ref":"Mix.Tasks.Output.html","title":"mix output","type":"task"},{"doc":"","ref":"Mix.Tasks.Output.html#put_error/1","title":"Mix.Tasks.Output.put_error/1","type":"function"},{"doc":"","ref":"Mix.Tasks.Output.html#put_info/1","title":"Mix.Tasks.Output.put_info/1","type":"function"},{"doc":"","ref":"Mix.Tasks.Output.html#put_success/1","title":"Mix.Tasks.Output.put_success/1","type":"function"},{"doc":"Interaction between `Bio.Sequence` objects and `Bio.Restriction.Enzyme`s.\n\nThe primary function is `digest/2`. The `digest/2` function works by recursively\nbreaking down a binary and checking to see if the pattern for a given enzyme\nexists within it.\n\n> ##","ref":"Bio.Restriction.html","title":"Bio.Restriction","type":"module"},{"doc":"> Initially I had thought to just get the data and apply it. Having only been\n> familiar with quite a small sub-set of the possible digestion outcomes. That\n> said, I did some reading and it seems that having `digest/2` be type specific\n> to the type and sub-type of the enzyme is the best approach. That means that I\n> need to re-write the parser for the REBASE data. Which means that there's more\n> work to be done! When is that ever not true...\n> Anyway you probably don't want to use this until then.\n\n> ##","ref":"Bio.Restriction.html#module-redesign-incoming-warning","title":"Redesign Incoming {: .warning} - Bio.Restriction","type":"module"},{"doc":"> Currently we don't support enzymes that have two cut sites, or\n> enzymes with ambiguous DNA recognition.\n\n\n> ##","ref":"Bio.Restriction.html#module-missing-functionality-warning","title":"Missing Functionality {: .warning} - Bio.Restriction","type":"module"},{"doc":"> The enzyme HpyUM037X is removed from the set, since it has two conflicting\n> entries in the emboss data. If you can resolve this distinction, please feel\n> free to either contribute a fix, or open an issue that explains how one would\n> be implemented.","ref":"Bio.Restriction.html#module-missing-data-warning","title":"Missing Data {: .warning} - Bio.Restriction","type":"module"},{"doc":"Digest takes in a string, anticipated to be a DNA sequence, and extracts the\ncomponents of the string as a tuple that would remain after digestion with a\ngiven restriction enzyme.","ref":"Bio.Restriction.html#digest/2","title":"Bio.Restriction.digest/2","type":"function"},{"doc":"iex> Bio.Restriction.digest(\"ttagatgacgtctcgattagagt\", Bio.Restriction.Enzyme.get!(:bsmbi))\n    [\"ttagatgacgtctcg\", \"attagagt\"]\n\nCurrently this will work for enzymes that look back as well:\n\n    iex> Bio.Restriction.digest(\"ggatgcagatcagacgaggattga\", Bio.Restriction.Enzyme.get!(:bsp143i))\n    [\"ggatgc\", \"agatcagacgaggattga\"]\n\nIt does not yet work on enzymes that would produce digestions with three parts\nsuch as NmeDI, nor will it work on enzymes whose recognition pattern is\ndefined using ambiguous DNA (even simply N).","ref":"Bio.Restriction.html#digest/2-examples","title":"Examples - Bio.Restriction.digest/2","type":"function"},{"doc":"This module represents the basic data of a restriction enzyme, as well as\nfunctions for accessing them.\n\nThe core struct contains information regarding the cut sites, bluntness,\nname, and recognition site of the restriction enzyme that it represents.\n\nThe structs declaration is wrapped in a function that is prefixed by an\n`_`, this allows the import of the module without overloading the context\nwith a lot of extraneous functions. The primary interface for accessing\nenzymes is the `get/1` function.","ref":"Bio.Restriction.Enzyme.html","title":"Bio.Restriction.Enzyme","type":"module"},{"doc":"The primary struct for interacting with restriction enzymes","ref":"Bio.Restriction.Enzyme.html#__struct__/0","title":"Bio.Restriction.Enzyme.__struct__/0","type":"function"},{"doc":"","ref":"Bio.Restriction.Enzyme.html#all/0","title":"Bio.Restriction.Enzyme.all/0","type":"function"},{"doc":"Get an enzyme struct by name, where name is either a binary or atom and\ncase insensitive. Returning an error tuple, the error case is a\nthree-tuple with the requested enzyme name as well as the error:\n\n    {:error, :undef_enzyme,  }\n\n# Examples\n    iex>Bio.Restriction.Enzyme.get(:CviRI)\n    {:ok, %Bio.Restriction.Enzyme{\n        blunt?: true,\n        cut_1: 2,\n        cut_2: 2,\n        cut_3: 0,\n        cut_4: 0,\n        name: \"CviRI\",\n        pattern: \"tgca\"\n      }}\n\n    iex>Bio.Restriction.Enzyme.get(\"CviRI\")\n    {:ok, %Bio.Restriction.Enzyme{\n        blunt?: true,\n        cut_1: 2,\n        cut_2: 2,\n        cut_3: 0,\n        cut_4: 0,\n        name: \"CviRI\",\n        pattern: \"tgca\"\n      }}\n\n    iex>Bio.Restriction.Enzyme.get(:not_an_enzyme)\n    {:error, :undef_enzyme, \"not_an_enzyme\"}","ref":"Bio.Restriction.Enzyme.html#get/1","title":"Bio.Restriction.Enzyme.get/1","type":"function"},{"doc":"Like `get/1`, but raises for unknown enzymes or returns the struct.\n\n# Examples\n    iex>Bio.Restriction.Enzyme.get!(:CviRI)\n    %Bio.Restriction.Enzyme{\n        blunt?: true,\n        cut_1: 2,\n        cut_2: 2,\n        cut_3: 0,\n        cut_4: 0,\n        name: \"CviRI\",\n        pattern: \"tgca\"\n      }\n\n    iex>Bio.Restriction.Enzyme.get!(\"CviRI\")\n    %Bio.Restriction.Enzyme{\n        blunt?: true,\n        cut_1: 2,\n        cut_2: 2,\n        cut_3: 0,\n        cut_4: 0,\n        name: \"CviRI\",\n        pattern: \"tgca\"\n      }","ref":"Bio.Restriction.Enzyme.html#get!/1","title":"Bio.Restriction.Enzyme.get!/1","type":"function"},{"doc":"Return a supplier's full name from a code.\n\nSupplier information is encoded in a list of atoms on each struct, which\ncan be used to filter the enzymes that you make available or ensure that\nthey are available through a given entity.\n\nThis function allows you to get the full name for a given entity from that\ncode. Codes can be given as either an atom or a binary, either will be\nmodified to ensure case insensitive comparisons.\n\n# Examples\n    iex>Bio.Restriction.Enzyme.get_supplier(:N)\n    \"New England Biolabs\"\n\n    iex>Bio.Restriction.Enzyme.get_supplier(\"b\")\n    \"Thermo Fisher Scientific\"","ref":"Bio.Restriction.Enzyme.html#get_supplier/1","title":"Bio.Restriction.Enzyme.get_supplier/1","type":"function"},{"doc":"","ref":"Bio.Restriction.Enzyme.html#t:supplier_code/0","title":"Bio.Restriction.Enzyme.supplier_code/0","type":"type"},{"doc":"","ref":"Bio.Restriction.Enzyme.html#t:supplier_list/0","title":"Bio.Restriction.Enzyme.supplier_list/0","type":"type"},{"doc":"","ref":"Bio.Restriction.Enzyme.html#t:t/0","title":"Bio.Restriction.Enzyme.t/0","type":"type"}]}